@@ -107,11 +107,11 @@ class RPCMethod:
 class BlockchairAPI:
     MAIN_ENDPOINT = 'https://api.blockchair.com/bitcoin/'
     MAIN_ADDRESS_API = MAIN_ENDPOINT + 'dashboards/address/{}'
-    MAIN_TX_PUSH_API = MAIN_ENDPOINT + 'dashboards/push/transaction'
+    MAIN_TX_PUSH_API = MAIN_ENDPOINT + 'push/transaction'
     MAIN_TX_API = MAIN_ENDPOINT + 'raw/transaction/{}'
     TEST_ENDPOINT = 'https://api.blockchair.com/bitcoin/testnet/'
     TEST_ADDRESS_API = TEST_ENDPOINT + 'dashboards/address/{}'
-    TEST_TX_PUSH_API = TEST_ENDPOINT + 'dashboards/push/transaction'
+    TEST_TX_PUSH_API = TEST_ENDPOINT + 'push/transaction'
     TEST_TX_API = TEST_ENDPOINT + 'raw/transaction/{}'
     TX_PUSH_PARAM = 'data'
 
@@ -285,7 +285,7 @@ class BlockchairAPI:
             unspents.extend(
                 Unspent(
                     utxo['value'],
-                    block_height - utxo['block_id'],
+                    block_height - utxo['block_id'] + 1 if utxo['block_id'] != -1 else 0,
                     script_pubkey,
                     utxo['transaction_hash'],
                     utxo['index'],
@@ -460,7 +460,7 @@ class BlockstreamAPI:
             [
                 Unspent(
                     tx["value"],
-                    block_height - tx["status"]["block_height"] if tx["status"]["confirmed"] else 0,
+                    block_height - tx["status"]["block_height"] + 1 if tx["status"]["confirmed"] else 0,
                     script_pubkey,
                     tx["txid"],
                     tx["vout"],
@@ -490,7 +490,7 @@ class BlockstreamAPI:
         return [
             Unspent(
                 tx["value"],
-                block_height - tx["status"]["block_height"] if tx["status"]["confirmed"] else 0,
+                block_height - tx["status"]["block_height"] + 1 if tx["status"]["confirmed"] else 0,
                 script_pubkey,
                 tx["txid"],
                 tx["vout"],
